@@ -4,14 +4,10 @@
 import os
 
 application_name = 'toever'
-version = '1.9.4'
-
+version = '1.9.5'
 user_filepath = os.environ['HOME'] + '/.' + application_name
-tmp_filepath = '/tmp/toever'
 sandbox = False
-evernote_url = 'https://www.evernote.com'
-token_geturl = 'https://www.evernote.com/api/DeveloperToken.action'
-
+evernote_url = 'https://sandbox.evernote.com'
 if sandbox:
     evernote_url = 'https://sandbox.evernote.com'
-    token_geturl = 'https://sandbox.evernote.com/api/DeveloperToken.action'
+token_geturl = evernote_url + '/api/DeveloperToken.action'
