@@ -16,7 +16,6 @@ import hashlib
 import ConfigParser
 import keyring
 import chardet
-import shutil
 import config as sys_config
 
 
@@ -266,13 +265,6 @@ def main():
             return toever.getCreateNoteError()
         return 0
 
-    # Binary Check
-    shutil.copyfileobj(sys.stdin, open(sys_config.tmp_filepath, 'w'))
-    if Util.isBinary(open(sys_config.tmp_filepath).read()):
-        return textui.colored.red("Please set the filename in the '-f' option")
-    sys.stdin = open(sys_config.tmp_filepath)
-    os.remove(sys_config.tmp_filepath)
-
     try:
         toever.setContent()
     except:
